@@ -1,6 +1,19 @@
 import os
 import logging 
 
+g_directory_stack = []
+
+def pushd(target):
+    g_directory_stack.append(os.path.join(os.path.abspath("."), target))
+    os.chdir(target)
+
+def popd():
+    if len(g_directory_stack) > 1:
+        g_directory_stack.pop(-1)
+        os.chdir(g_directory_stack[-1])
+    if len(g_directory_stack) == 1:
+        os.chdir(g_directory_stack[0])
+
 def create_directory_if_not_exists(path, level=logging.DEBUG):
     logger = logging.getLogger("logger")
     logger.setLevel(level)
